@@ -1,4 +1,4 @@
-use savvy::{OwnedIntegerSxp, OwnedRealSxp, OwnedStringSxp};
+use savvy::{OwnedIntegerSexp, OwnedRealSexp, OwnedStringSexp};
 
 /// An intermediate form of the extracted path information to convert to a tibble.
 pub struct PathTibble {
@@ -14,35 +14,35 @@ pub struct PathTibble {
     pub triangle_id: Option<Vec<i32>>,
 }
 
-impl TryFrom<PathTibble> for savvy::SEXP {
+impl TryFrom<PathTibble> for savvy::Sexp {
     type Error = savvy::Error;
 
     fn try_from(value: PathTibble) -> savvy::Result<Self> {
         let len = if value.triangle_id.is_none() { 4 } else { 5 };
-        let mut out = savvy::OwnedListSxp::new(len, true)?;
+        let mut out = savvy::OwnedListSexp::new(len, true)?;
 
-        out.set_name_and_value(0, "x", <OwnedRealSxp>::try_from(value.x.as_slice())?)?;
-        out.set_name_and_value(1, "y", <OwnedRealSxp>::try_from(value.y.as_slice())?)?;
+        out.set_name_and_value(0, "x", <OwnedRealSexp>::try_from(value.x.as_slice())?)?;
+        out.set_name_and_value(1, "y", <OwnedRealSexp>::try_from(value.y.as_slice())?)?;
         out.set_name_and_value(
             2,
             "glyph_id",
-            <OwnedIntegerSxp>::try_from(value.glyph_id.as_slice())?,
+            <OwnedIntegerSexp>::try_from(value.glyph_id.as_slice())?,
         )?;
         out.set_name_and_value(
             3,
             "path_id",
-            <OwnedIntegerSxp>::try_from(value.path_id.as_slice())?,
+            <OwnedIntegerSexp>::try_from(value.path_id.as_slice())?,
         )?;
 
         if let Some(triangle_id) = value.triangle_id {
             out.set_name_and_value(
                 4,
                 "triangle_id",
-                <OwnedIntegerSxp>::try_from(triangle_id.as_slice())?,
+                <OwnedIntegerSexp>::try_from(triangle_id.as_slice())?,
             )?;
         }
 
-        Ok(out.into())
+        out.into()
     }
 }
 
@@ -55,29 +55,37 @@ pub struct FontDBTibble {
     pub style: Vec<String>,
 }
 
-impl TryFrom<FontDBTibble> for savvy::SEXP {
+impl TryFrom<FontDBTibble> for savvy::Sexp {
     type Error = savvy::Error;
     fn try_from(value: FontDBTibble) -> savvy::Result<Self> {
-        let mut out = savvy::OwnedListSxp::new(5, true)?;
+        let mut out = savvy::OwnedListSexp::new(5, true)?;
 
-        out.set_name_and_value(0, "x", <OwnedStringSxp>::try_from(value.source.as_slice())?)?;
-        out.set_name_and_value(1, "y", <OwnedIntegerSxp>::try_from(value.index.as_slice())?)?;
+        out.set_name_and_value(
+            0,
+            "x",
+            <OwnedStringSexp>::try_from(value.source.as_slice())?,
+        )?;
+        out.set_name_and_value(
+            1,
+            "y",
+            <OwnedIntegerSexp>::try_from(value.index.as_slice())?,
+        )?;
         out.set_name_and_value(
             2,
             "family",
-            <OwnedStringSxp>::try_from(value.family.as_slice())?,
+            <OwnedStringSexp>::try_from(value.family.as_slice())?,
         )?;
         out.set_name_and_value(
             3,
             "weight",
-            <OwnedStringSxp>::try_from(value.weight.as_slice())?,
+            <OwnedStringSexp>::try_from(value.weight.as_slice())?,
         )?;
         out.set_name_and_value(
             4,
             "style",
-            <OwnedStringSxp>::try_from(value.style.as_slice())?,
+            <OwnedStringSexp>::try_from(value.style.as_slice())?,
         )?;
 
-        Ok(out.into())
+        out.into()
     }
 }
